References
-------------------

Standards
~~~~~~~~~~~~~~~~

The set of standards currently implemented is based on the following references:


* BIS/EBA Standardized Credit Risk assessment of Project Finance
* Equator Principles for Project Finance
* PCAF Emissions Accounting and Reporting for Project Finance
* GHG Protocol for Projects
* GHG Protocol for Community-scale Emissions


Publications
~~~~~~~~~~~~~~~


* Fong, W. K., M. Sotos, M. Doust, S. Schultz, A. Marques, and C. Deng-Beck (2014). Global Protocol for Community-Scale Greenhouse Gas Emission Inventories: An Accounting and Reporting Standard for Cities. World Resources Institute. C40 Cities Climate Leadership Group; Local Governments for Sustainability ICLEI. 1, 1–176.
